Package: EpiDISH
Title: Epigenetic Dissection of Intra-Sample-Heterogeneity
Version: 2.28.0
Description: EpiDISH is a R package to infer the proportions of a
        priori known cell-types present in a sample representing a
        mixture of such cell-types. Right now, the package can be used on DNAm 
        data of blood-tissue of any age, from birth to old-age, generic epithelial
	tissue and breast tissue. Besides, the package provides a function that allows 
        the identification of differentially methylated cell-types and their 
        directionality of change in Epigenome-Wide Association Studies.
Date: 2026-03-13
Authors@R: c(person("Andrew E.", "Teschendorff", role=c("aut"), email="andrew@picb.ac.cn"),
        person("Shijie C.", "Zheng", role=c("aut", "cre"), email="shijieczheng@gmail.com"))
Depends: R (>= 4.1)
Imports: MASS, e1071, quadprog, parallel, stats, matrixStats, stringr,
        locfdr, Matrix, genefilter
Suggests: roxygen2, GEOquery, BiocStyle, knitr, rmarkdown, Biobase,
        testthat
VignetteBuilder: knitr
License: GPL-2
LazyData: true
RoxygenNote: 7.1.2
URL: https://github.com/sjczheng/EpiDISH
BugReports: https://github.com/sjczheng/EpiDISH/issues
biocViews: DNAMethylation, MethylationArray, Epigenetics,
        DifferentialMethylation, ImmunoOncology
git_url: https://git.bioconductor.org/packages/EpiDISH
git_branch: RELEASE_3_23
git_last_commit: 2574adb
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:05:18 UTC; biocbuild
Author: Andrew E. Teschendorff [aut],
  Shijie C. Zheng [aut, cre]
Maintainer: Shijie C. Zheng <shijieczheng@gmail.com>
Built: R 4.6.0; ; 2026-04-29 04:41:52 UTC; unix
