# Generated by roxygen2: do not edit by hand

export(CellDMC)
export(ConstructDNAmPanel)
export(DoMetaEfron)
export(epidish)
export(hepidish)
import(locfdr)
import(matrixStats)
import(parallel)
import(stats)
importFrom(MASS,rlm)
importFrom(Matrix,rankMatrix)
importFrom(e1071,svm)
importFrom(genefilter,fastT)
importFrom(matrixStats,rowMaxs)
importFrom(matrixStats,rowMeans2)
importFrom(matrixStats,rowMedians)
importFrom(matrixStats,rowMins)
importFrom(quadprog,solve.QP)
importFrom(stats,p.adjust)
importFrom(stats,p.adjust.methods)
importFrom(stats,pt)
importFrom(stringr,str_c)
importFrom(utils,head)
